/**
 * Parses Lambda Layer ARNs for a function
 */
export declare class FunctionLayerArnParser {
    private arnPattern;
    /**
     * Parse the layers for a function
     * @param layers - Layers to be attached to the function
     * @param functionName - Name of the function
     * @returns Valid layers for the function
     * @throws AmplifyUserError if the layer ARN is invalid
     * @throws AmplifyUserError if the number of layers exceeds the limit
     */
    parseLayers(layers: Record<string, string>, functionName: string): Record<string, string>;
    /**
     * Validate the ARN format for a Lambda Layer
     */
    private isValidLayerArn;
    /**
     * Validate the number of layers attached to a function
     * @see https://docs.aws.amazon.com/lambda/latest/dg/gettingstarted-limits.html#function-configuration-deployment-and-execution
     */
    private validateLayerCount;
}
//# sourceMappingURL=layer_parser.d.ts.map